#! /bin/bash

#version 1.7
# Version 1.2. Based on version 1.1, which containc only hungarian filenames, and comments, and internationalized as its messages. In these versions (1.1 and 1.2) all the  messages comes from an separate file. Therefore, to set an other language, it is enough to create a file containing the messages in the target language. This file have to be placed in the "local" directory (tester/main/local), and name as messages_xx, where "xx" refers to the language (hu: hungarian, en: english, ge: german, etc). When it is ready, write the language code of the new language in the file tester/main/language. 

# Tricky!
# Messages comes from the file "messages", where each line contains one message. While reading, each line (each messages) will stored in a separate variable. It is not a nice solution, I know, but currently (Ethiopia, Mekelle, 29/04/2016) it is the simplest way, so I do this.

basedir=~/scan
cd $basedir

kdialog --msgbox "1.7"

# Check if temp/msg exists or not. This subdirectory serves as to store temporary the system messages.
if [ -d temp/msg ]
  then
    echo "msg already exists"
  else
    mkdir temp
    mkdir temp/msg
fi
#Querying display dimensions

display_width=$(xwininfo -root | grep Width | cut -d: -f2 | sed s'\ \\'g)
display_height=$(xwininfo -root | grep Height | cut -d: -f2 | sed s'\ \\'g)

#Well, these are the dimensions of the rrot window, but normally there are some decorations as well (tray, bar etc...)
#Therefore, to declare the maximum height and width of a display window, have to consider the top-bottom and side margins, and the thickness of the window-frame as well.

top_bottom_margin=40
side_margin=20
frame=20
default_window_height=$(($display_height - $(($top_bottom_margin *2)) - $frame))
default_window_width=$(($display_width - $(($side_margin * 2)) - $frame))
small_menu_size=200
large_menu_size=400

default_window_ratio=$(( $(($default_window_width * 1000)) / $default_window_height ))

lang=$(cat main/language)
message="main/local/messages_$lang"


_yes_=$(cat $message | head -n1)
_no_=$(cat $message | head -n2 | tail -n1)
name1=$(cat $message | head -n3 | tail -n1)
name2=$(cat $message | head -n4 | tail -n1)
age1=$(cat $message | head -n5 | tail -n1)
age2=$(cat $message | head -n6 | tail -n1)
select1=$(cat $message | head -n7 | tail -n1)
school1=$(cat $message | head -n8 | tail -n1)
school2=$(cat $message | head -n9 | tail -n1)
school3=$(cat $message | head -n10 | tail -n1)
school4=$(cat $message | head -n11 | tail -n1)
school5=$(cat $message | head -n12 | tail -n1)
school6=$(cat $message | head -n13 | tail -n1)
calibation1=$(cat $message | head -n14 | tail -n1)
assign=$(cat $message | head -n15 | tail -n1)
questions=$(cat $message | head -n16 | tail -n1)
calibration2=$(cat $message | head -n17 | tail -n1)
go=$(cat $message | head -n18 | tail -n1)
cat $message | head -n19 | tail -n1 | grep [a-z,0-9] > temp/msg/voice # OK
test_question=$(cat $message | head -n20 | tail -n1)
select2=$(cat $message | head -n21 | tail -n1)
yes_no=$(cat $message | head -n22 | tail -n1)
cat $message | head -n23 | tail -n1 | grep [a-z,0-9] > temp/msg/clip # OK
image=$(cat $message | head -n24 | tail -n1)
mark=$(cat $message | head -n25 | tail -n1)
select3=$(cat $message | head -n26 | tail -n1)
last=$(cat $message | head -n27 | tail -n1)
cat $message | head -n28 | tail -n1 | grep [a-z,0-9] > temp/msg/finish


#Requesting the name of the patient

DATE=$(date +%Y_%m_%d_%H_%M)
PATIENT=$(kdialog --inputbox "$name2" --title "$name1")
AGE=$(kdialog --inputbox "$age2" --title "$age1")
ANSWER=$(kdialog --combobox "<big>$select1</big>" "$school1" "$school2" "$school3" "$school4" "$school5" "$school6")

	echo "$PATIENT" > temp/name
	cat temp/name | sed 's/[ \t]\+/_/g' > temp/name_
	NAME=$(cat temp/name_)

touch results/$NAME

rm -f temp/name*

echo "$NAME" >> results/$NAME
echo "$AGE" >> results/$NAME
case $ANSWER in
	"$school1")
		echo "1" >> results/$NAME;;
	
	"$school2")
		echo "2" >> results/$NAME;;

	"$school3")
		echo "3" >> results/$NAME;;

	"$school4")
		echo "4" >> results/$NAME;;
		
	"$school5")
		echo "5" >> results/$NAME;;

	"$school6")
		echo "6" >> results/$NAME;;
esac
echo "$DATE" >> results/$NAME

# Az adatstruktúra a 0.15-ös verziótól
# Általános szabály, hogy az feladatokra és a válaszokra fordított időt nanosecundum-ban tárolja!
#
#A fájl első sora a kitöltő name;
#a második sor az életkora;
#a harmadik sor a legmagasabb iskola végzettsége:
# - általános iskola, de nem végezte el az összes osztályt -- 1
# - elvégezte az általános iskola összes osztályát -- 2
# - szakiskola vagy középiskola érettségi nélkül -- 3
# - középiskola érettségivel vagy technikum -- 4
# - főiskola vagy egyetem -- 5
# - Ph.D. vagy egyenértékű -- 6
#a negyedik sora pedig a kitöltés dátuma.
#
#Az első adattömb (a calibrating és a calibrating vége közötti 9 szám) arra szolgál, hogy a tesztet kitöltő személy egérkezelési sebességéről kapjunk egy jó becslést, amellyel majd súlyozhatjuk a válaszadás sebességét. 
#E tömb első és utolsó számát a súlytényező kialakításakor nem vesszük figyelembe, csak a középső hét értéket.
#
#Egy üres sor kihagyás után jönnek a tulajdonképpeni teszt eredmények
#
# - A továbbiakban minden egyes feladat esetén először a feladat name olvasható (a file name).
# - Ezután, ha a feladat egyszerű szöveges feladat, akkor az elolvasáshoz szükéges idő szerepel. E feladatokban csak egy kérdés és egy válaszadás van.
# - A következő sor a válasz azonosítóját tartalmazza.
# - Az utolsó sorban a válaszadásra fordított idő van.
#PÉLDA:
# feladat_2
# 1320488706
# 1
# 565060923
#
#Ha a feladat hangzó szöveges (minden, "filenév.mp3" nevű fájl ilyen), vagy filmrészlet (avi) vagy kép értelmezése (jpg) a struktúra ugyanez, azzal a különbséggel, hogy a feladat elolvasásához szükséges idő hossza minden esetben "0".
#PÉLDA:
# andi_boldog_gyorsan.mp3
# 0
# 1
# 1078363311
#---------
# fargo_clip_2.avi
# 0
# 1
# 801835438
#----------
# arc_duhos_ijedt_1.jpg
# 0
# 1
# 46253279309
#
#A metafóra jellegű feladatok eredményének értelmezése az alábbi:
# - a feladat (file) name
# - a feladat elolvasásának ideje
# - az első válasz kódja
# - az első válaszra fordított idő
# - a második válasz kódja
# - a második válaszra fordított idő
#
#PÉLDA:
# metafora_1
# 8296875238
# 2
# 4534481273
#
# 1
# 4835655652
#
#Vannak nem metafóra jellegű, de két kérdést és válaszadást tartalmazó feladatok. Ezek eredményeinek értelmezése megegyezik a metafórás feladatokével.
#
#PÉLDA:
# feladat_1
# 6668184021
# 1
# 1834661326
#
# 2
# 3392587751
#----------------------------------------------------------------------------------------------------------------

#A tulajdonképpeni program. 
INT=1

cd tasks

#személyi calibrating, Az egérkezelés sebességét mérő "feladatok" ----------------------------------------------

echo "" >> ../results/$NAME								
echo "calibrating" >> ../results/$NAME								
for b in $(ls ../main/local/calibrating/calibrating_*_$lang)
	do
		tail -n19 $b | head -n5 > ../temp/text
		tail -n9 $b | head -n1 > ../temp/first
		tail -n3 $b | head -n1 > ../temp/second
		WIDTH_1=$(tail -n14 $b | head -n1)
		HEIGHT_1=$(tail -n13 $b | head -n1)
		WIDTH_2=$(tail -n8 $b | head -n1)
		HEIGHT_2=$(tail -n7 $b | head -n1)
		WIDTH_3=$(tail -n2 $b | head -n1)
		HEIGHT_3=$(tail -n1 $b)
		BEFORE=$(date +%s%N)
		
		kdialog --title "$calibration1" --textbox "../temp/text" $WIDTH_1 $HEIGHT_1
		AFTER=$(date +%s%N)
		TIME_SPENT=$(expr $AFTER - $BEFORE)
		echo "$TIME_SPENT" >> ../results/$NAME
	 		
		BEFORE_2=$(date +%s%N)

		kdialog --title "$calibration1" --textbox "../temp/first" $HEIGHT_2 $WIDTH_2
		AFTER_2=$(date +%s%N)
		TIME_SPENT_2=$(expr $AFTER_2 - $BEFORE_2)
		echo "$TIME_SPENT_2" >> ../results/$NAME
								
		BEFORE_3=$(date +%s%N)	
		
		kdialog --title "$calibration1" --textbox "../temp/second" $HEIGHT_3 $WIDTH_3
		AFTER_3=$(date +%s%N)
		TIME_SPENT_3=$(expr $AFTER_3 - $BEFORE_3)
		echo "$TIME_SPENT_3" >> ../results/$NAME
done

rm -f ../temp/text
rm -f ../temp/first
rm -f ../temp/second

echo "$calibration2" >> ../results/$NAME
echo "" >> ../results/$NAME


#--------------------------------------------------------------


#olvassuk a lista nevű file tartalmát. Ebben vannak felsorolva, tetszés szerinti sorrendben a használandó állományok
for i in $(cat list) 
	do
	#LÉNYEGES! Itt választjuk ki a második oszlopot a "list" fájlból! Ha a list ájl nem tartalmazza a prefixeket, szóközzel elválasztva, hibás lesz a program futása. Le fog állni.
	#Persze, ki lehetne írni csak magát az eredeti $i értéket is, hszen az pont ugyanaz, mint a $typ|$i. Ezzel csak az lehet a baj, ha a prefix ($typ), netán éppen png, jpg, avi, vagy ilyesmi lenne.
	# Ezt lehet elkerülni ezzel a megoldással, noha persze köülényesnek tűnik :)
	typ=$(echo $i | cut -d"|" -f1)
	i=$(echo $i | cut -d"|" -f2)
		if [[ $i =~ ".mp3" ]] #A hangfájlok kötelezően mp3 formátumúak legyenek -- OK
			then	
				echo "$typ|$i" >> ../results/$NAME
				echo "0" >> ../results/$NAME				
				kdialog --textbox "../temp/msg/voice"
				mplayer $i #& sleep 2s
			else
				if [[ $i =~ "vquestion" ]] # A hang utáni kérdés mindig egy vquestion nevű file legyen
					then
						ONE=$(tail -n7 $i | head -n3)
						OTHER=$(tail -n3 $i)
				
						BEFORE=$(date +%s%N)
						kdialog --title "$questions" --yes-label "2" --no-label "1" --yesno "<h4>$select3</h4>\n\n<h4>1</h4>$ONE\n\n<h4>2</h4>$OTHER"

							case $? in
								"1")
									echo "1" >> ../results/$NAME;;
	
								"0")
									echo "2" >> ../results/$NAME;;
							esac
			
						AFTER=$(date +%s%N)

						TIME_SPENT=$(expr $AFTER - $BEFORE)
						
						echo "$TIME_SPENT" >> ../results/$NAME
						echo "" >> ../results/$NAME
				fi
		fi
#-----------------------------------------------------
		if [[ $i =~ "task" ]] #ezek az egyszerű feladatok, igen-nem választ várunk -- OK
			then
				echo "$typ|$i" >> ../results/$NAME								
				head -n9 $i | tail -n8 | grep [a-z,0-9]> ../temp/msg/task_text_1
				FIRST=$(tail -n7 $i | head -n3)
				SECOND=$(tail -n3 $i)
				BEFORE=$(date +%s%N)
				kdialog --title "$questions" --textbox "../temp/msg/task_text_1"
				AFTER=$(date +%s%N)
				TIME_SPENT=$(expr $AFTER - $BEFORE)
				echo "$TIME_SPENT" >> ../results/$NAME
				BEFORE_2=$(date +%s%N)
				kdialog --yes-label "$_yes_" --no-label "$_no_" --title "$qustions" --yesno "<h4>$yes_no</h4> \n\n$FIRST"
				case $? in
					"1")
						echo "1" >> ../results/$NAME;;
					"0")
						echo "2" >> ../results/$NAME;;
				esac
			
				AFTER_2=$(date +%s%N)
				TIME_SPENT_2=$(expr $AFTER_2 - $BEFORE_2)
				echo "$TIME_SPENT_2" >> ../results/$NAME
#				echo "" >> ../results/$NAME
				BEFORE_3=$(date +%s%N)	
				kdialog --yes-label "$_yes_" --no-label "$_no_" --title "$qustions" --yesno "<h4>$yes_no</h4> \n\n$SECOND"

				case $? in
					"1")
						echo "1" >> ../results/$NAME;;
					"0")
						echo "2" >> ../results/$NAME;;
				esac
				AFTER_3=$(date +%s%N)
				TIME_SPENT_3=$(expr $AFTER_3 - $BEFORE_3)
				echo "$TIME_SPENT_3" >> ../results/$NAME
				echo "" >> ../results/$NAME
		fi
#------Itt jön a fekete leves: valahogy kezelni kellene a metaforás feladatokat és kérdéseket is.------------
		if [[ $i =~ "metafora" ]] #ezek a metafora feladatok -- OK
			then
				echo "$typ|$i" >> ../results/$NAME
				head -n8 $i | tail -n7 | grep [a-z,0-9] > ../temp/msg/metafora_text_1
				FIRST_KERDES=$(tail -n12 $i | head -n2)
				FIRST_KERDES_1=$(tail -n9 $i | head -n2)
				FIRST_KERDES_2=$(tail -n6 $i | head -n2)
				SECOND_KERDES=$(tail -n3 $i)
				BEFORE=$(date +%s%N)
				kdialog --title "$questions" --textbox "../temp/msg/metafora_text_1"
				AFTER=$(date +%s%N)
				TIME_SPENT=$(expr $AFTER - $BEFORE)
				echo "$TIME_SPENT" >> ../results/$NAME
				BEFORE_2=$(date +%s%N)
				kdialog --yes-label "1" --no-label "2" --title "$questions" --yesno "<h4>$FIRST_KERDES</h4>\n\n<h4>1</h4>\n$FIRST_KERDES_1 \n\n<h4>2</h4>\n$FIRST_KERDES_2"
				case $? in
					"1")
						echo "1" >> ../results/$NAME;;
					"0")
						echo "2" >> ../results/$NAME;;
				esac
			
				AFTER_2=$(date +%s%N)
				TIME_SPENT_2=$(expr $AFTER_2 - $BEFORE_2)
				echo "$TIME_SPENT_2" >> ../results/$NAME
				echo "" >> ../results/$NAME


	#második kérdés-------


				BEFORE_3=$(date +%s%N)	
				kdialog --yes-label "$_yes_" --no-label "$_no_" --title "$questions" --yesno "<h4>$yes_no</h4>\n\n$SECOND_KERDES"
				case $? in
					"1")
						echo "1" >> ../results/$NAME;;
					"0")
						echo "2" >> ../results/$NAME;;
				esac
			
				AFTER_3=$(date +%s%N)
				TIME_SPENT_3=$(expr $AFTER_3 - $BEFORE_3)
				echo "$TIME_SPENT_3" >> ../results/$NAME
				echo "" >> ../results/$NAME
		fi
#------------------KÉPEK KEZELÉSE

		if [[ $i =~ ".jpg" ]] # a kétválasztásos képek formátuma mindig jpg!
			then	

				echo "$typ|$i" >> ../results/$NAME
				echo "0" >> ../results/$NAME
				
				#calculating if the height or the width of the image is greater. The greatest number will assign to the variable 'main_size'
				#calculating the size of the image
				words=$(file $i | wc -w)
				words=$(($words - 2 ))
				img_width=$(file $i | cut -d" " -f$words | sed s'\,\\'g | cut -dx -f1)
				img_height=$(file $i | cut -d" " -f$words | sed s'\,\\'g | cut -dx -f2)
				img_ratio=$(($img_width * 1000 / $img_height))
				
				until [ $img_height -lt $(($default_window_height - 80)) -a $img_width -lt $(($default_window_width - $small_menu_size)) ];do
					
					
					img_height=$(( $(( $img_width * 1000)) / $img_ratio ))
					img_width=$(($((  $img_ratio * $img_height  )) / 1000 ))
	
					img_width=$(($img_width - 10))
					#echo $img_width
				done
				
				BEFORE=$(date +%s%N)
				KEP_KERDES=$(ls $i | cut -d. -f1)
				ONE=$(tail -n7 $KEP_KERDES\_\iquestion | head -n3)
				OTHER=$(tail -n3 $KEP_KERDES\_\iquestion)
	
				z=$((  $(($default_window_width / 2))  -  $(($(($img_width + $small_menu_size)) / 2))  ))
				m1=$(( $(($display_height / 2 )) - $(($(($img_height + 80)) / 2))  ))

				kdialog --title "$question" --textinputbox "<img src='$i' width='$img_width'>" --geometry $img_width"x"$img_height+$z+$m1&
				kdialog --menu "$select2" 1 "$ONE" 0 "$OTHER" --geometry $small_menu_size"x"$small_menu_size+$(($z + $img_width + $frame + 10))+$m1
				killall kdialog

			case $? in
				"1")
					echo "1" >> ../results/$NAME;;
					"0")
					echo "2" >> ../results/$NAME;;
			esac
			
			AFTER=$(date +%s%N)
			TIME_SPENT=$(expr $AFTER - $BEFORE)
			echo "$TIME_SPENT" >> ../results/$NAME
			echo "" >> ../results/$NAME
				
		fi
#-------------------------------VIDEÓK kezelése
		if [[ $i =~ ".avi" ]] #A video fájlok kötelezően avi formátumúak legyenek -- OK
			then	
				echo "$typ|$i" >> ../results/$NAME
				echo "0" >> ../results/$NAME
				kdialog --title "$questions" --textbox "../temp/msg/clip"
				mplayer -fs $i
			else
				if [[ $i =~ "mquestion" ]] # A film utáni kérdés mindig egy mquestion nevű file legyen
					then
						ONE=$(tail -n11 $i | head -n3)
						OTHER=$(tail -n7 $i | head -n3)
						HARMADIK=$(tail -n3 $i)
						BEFORE=$(date +%s%N)
						ANSWER=$(kdialog --title "$questions" --menu "<h4>$select1</h4>" 1 "$ONE" 2 "$OTHER" 3 "$HARMADIK"  --geometry $large_menu_width"x"$large_menu_height+$(($(($display_width /2 )) - $(($large_menu_width / 2 ))))+$(($((display_height / 2)) - $(($large_menu_height / 2)))))
						case $ANSWER in
							"1")
								echo "a" >> ../results/$NAME;;
							"2")
								echo "b" >> ../results/$NAME;;
							"3")
								echo "c" >> ../results/$NAME;;
						esac
			
						AFTER=$(date +%s%N)
						TIME_SPENT=$(expr $AFTER - $BEFORE)
						echo "$TIME_SPENT" >> ../results/$NAME
						echo "" >> ../results/$NAME
				fi
		fi
#------------Négyválasztásos kérdések--------------------------------------------------
		if [[ $i =~ ".png" ]] #fontos sajátosság, hogy a négyválasztásos képek formátuma png legyen!
			then	
				echo "$typ|$i" >> ../results/$NAME
				echo "0" >> ../results/$NAME
				
				#calculating if the height or the width of the image is greater. The greatest number will assign to the variable 'main_size'
				#calculating the size of the image
				words=$(file $i | wc -w)
				words=$(($words - 2 ))
				
				 
				img_width=$(file $i | cut -d, -f2 | sed s'/ //'g | cut -dx -f1)
				img_height=$(file $i | cut -d, -f2 | sed s'/ //'g | cut -dx -f2)
				img_ratio=$(($img_width * 1000 / $img_height))
				
				until [ $img_height -lt $(($default_window_height - 80)) -a $img_width -lt $(($default_window_width - $small_menu_size)) ];do
					
					img_height=$(( $(( $img_width * 1000)) / $img_ratio ))
					img_width=$(($((  $img_ratio * $img_height  )) / 1000 ))
	
					img_width=$(($img_width - 10))
					#echo $img_width
				done
				
				BEFORE=$(date +%s%N)
				KEP_KERDES=$(ls $i | cut -d. -f1)
				ONE=$(tail -n7 $KEP_KERDES\_\iquestion | head -n3)
				OTHER=$(tail -n3 $KEP_KERDES\_\iquestion)
	
				z=$((  $(($default_window_width / 2))  -  $(($(($img_width + $small_menu_size)) / 2))  ))
				m1=$(( $(($display_height / 2 )) - $(($(($img_height + 80)) / 2)) ))

				kdialog --title "$question" --textinputbox "<img src='$i' width='$img_width'>" --geometry $img_width"x"$img_height+$z+$m1
				ANSWER=$(kdialog --menu "$mark" A "   A" B "   B" C "   C" D "   D" --geometry $small_menu_size"x"$small_menu_size+$(($z + $img_width + $frame + 10))+$m1)

				#ANSWER=$(zenity --list --width=200 --height=250 --text "$mark" --radiolist --column " " --column " " TRUE "A" FALSE B FALSE "C" FALSE D)
				case $ANSWER in
					"A")
						echo "a" >> ../results/$NAME;;
					"B")
						echo "b" >> ../results/$NAME;;
					"C")
						echo "c" >> ../results/$NAME;;
					"D")
						echo "d" >> ../results/$NAME;;
				esac
				TIME_SPENT=$(expr $AFTER - $BEFORE)
				echo "$TIME_SPENT" >> ../results/$NAME
				echo "" >> ../results/$NAME
		fi
INT=$(expr $INT + 1)
done

rm -f ./text_temp
# rm -fr ../temp
rm -f ../scan1.4.sh
kdialog --title "$last" --textbox "../temp/msg/finish"
